// 定义一个控件类,即function
function ZoomControl(){
  // 默认停靠位置和偏移量
  this.defaultAnchor = BMAP_ANCHOR_TOP_LEFT;
  this.defaultOffset = new BMap.Size(10, 10);
}
// 通过JavaScript的prototype属性继承于BMap.Control
ZoomControl.prototype = new BMap.Control();

// 自定义控件必须实现自己的initialize方法,并且将控件的DOM元素返回
// 在本方法中创建个div元素作为控件的容器,并将其添加到地图容器中
ZoomControl.prototype.initialize = function(map){
  // 创建一个DOM元素
  var div = document.createElement("div");
  // 添加文字说明
  div.appendChild(document.createTextNode("放大2级"));
  // 设置样式
  div.style.cursor = "pointer";
  div.style.border = "1px solid gray";
  div.style.backgroundColor = "white";
  // 绑定事件,点击一次放大两级
  div.onclick = function(e){
	map.setZoom(map.getZoom() + 2);
  }
  // 添加DOM元素到地图中
  map.getContainer().appendChild(div);
  // 将DOM元素返回
  return div;
}
// 定义Label的构造函数
function LabelOverlay(center, width, height, left, top, color, text){      
    this._center = center;      
    this._width = width;
    this._height = height;
    this._left = left;
    this._top = top;
    this._color = color;
    this._text = text;
}      
// 继承API的BMap.Overlay      
LabelOverlay.prototype = new BMap.Overlay();
  // 实现初始化方法    
LabelOverlay.prototype.initialize = function(map){      
// 保存map对象实例     
    this._map = map;          
// 创建div元素，作为自定义覆盖物的容器     
    var div = document.createElement("div");      
    div.style.position = "absolute";          
// 可以根据参数设置元素外观     
    div.style.width = this._width + "px";      
    div.style.height = this._height + "px";      
    div.style.color = this._color; 
    div.innerHTML = this._text;
// 将div添加到覆盖物容器中     
    map.getPanes().markerPane.appendChild(div);        
// 保存div实例     
    this._div = div;        
// 需要将div元素作为方法的返回值，当调用该覆盖物的show、     
// hide方法，或者对覆盖物进行移除时，API都将操作此元素。     
    return div;      
}
// 实现绘制方法     
LabelOverlay.prototype.draw = function(){      
// 根据地理坐标转换为像素坐标，并设置给容器      
   var position = this._map.pointToOverlayPixel(this._center);      
   this._div.style.left = position.x - this._left + "px";      
   this._div.style.top = position.y - this._top + "px";      
}
// 实现显示方法      
LabelOverlay.prototype.show = function(){      
    if (this._div){      
        this._div.style.display = "";      
    }      
}        
// 实现隐藏方法    
LabelOverlay.prototype.hide = function(){      
    if (this._div){      
        this._div.style.display = "none";      
    }      
}
// 添加自定义方法     
LabelOverlay.prototype.toggle = function(){      
    if (this._div){      
       if (this._div.style.display == ""){      
           this.hide();      
        }      
       else {      
           this.show();      
        }      
    }      
}

// 定义CIRCLE的构造函数    
function CircleOverlay(center, length, color){
    this._center = center;     
    this._length = length;      
    this._color = color;      
 }        
// 继承API的BMap.Overlay      
CircleOverlay.prototype = new BMap.Overlay();
  // 实现初始化方法    
// 实现初始化方法    
CircleOverlay.prototype.initialize = function(map){      
// 保存map对象实例     
    this._map = map;          
// 创建div元素，作为自定义覆盖物的容器 
    var div = document.createElement("canvas");
      div.style.position = "absolute";          
// 可以根据参数设置元素外观     
      div.style.width = this._length + "px";      
      div.style.height = this._length + "px";      
      div.style.border = "0px";
      var ctxlength=this._length/2;
    var ctx = div.getContext("2d");
//  var ctx = this._div.getContext("2d");
    ctx.beginPath();
    ctx.strokeStyle=this._color;
	ctx.arc(ctxlength,ctxlength,ctxlength,0,2*Math.PI);
	ctx.stroke();
    //div.style.position = "absolute";          
// 可以根据参数设置元素外观     
    //div.style.width = this._length + "px";      
    //div.style.height = this._length + "px";      
    //div.style.background = this._color;        
// 将div添加到覆盖物容器中     
    map.getPanes().markerPane.appendChild(div);        
// 保存div实例     
    this._div = div;        
// 需要将div元素作为方法的返回值，当调用该覆盖物的show、     
// hide方法，或者对覆盖物进行移除时，API都将操作此元素。     
    return div;      
}
// 实现绘制方法     
CircleOverlay.prototype.draw = function(){      
// 根据地理坐标转换为像素坐标，并设置给容器      
     var position = this._map.pointToOverlayPixel(this._center);      
     this._div.style.left = position.x + "px";      
     this._div.style.top = position.y + "px";
}
// 实现显示方法      
CircleOverlay.prototype.show = function(){      
    if (this._div){      
        this._div.style.display = "";      
    }      
}        
// 实现隐藏方法    
CircleOverlay.prototype.hide = function(){      
    if (this._div){      
        this._div.style.display = "none";      
    }      
}
// 添加自定义方法     
CircleOverlay.prototype.toggle = function(){      
    if (this._div){      
       if (this._div.style.display == ""){      
           this.hide();      
        }      
       else {      
           this.show();      
        }      
    }      
}